@@ -9,7 +9,7 @@ from hkube_python_wrapper.storage.storage_manager import StorageManager
 from hkube_python_wrapper.communication.DataRequest import DataRequest
 from hkube_python_wrapper.cache.caching import Cache
 from ..config import config
-from hkube_python_wrapper.util.percentile import print_percentiles
+# from hkube_python_wrapper.util.percentile import print_percentiles
 
 
 class DataAdapter:
@@ -53,10 +53,6 @@ class DataAdapter:
                     data = self.tryGetDataFromPeerOrStorage(link)
 
                 setPath(inputArgs, k, data)
-        try:
-            print_percentiles(DataRequest.ping_times, title='Ping Times')
-        except Exception:
-            pass
 
         DataRequest.ping_times = []
 
